@@ -187,12 +187,26 @@ class Client:
     def current_user(self) -> Identity:
         """The identity details of the currently authenticated user.
 
-        See https://www.freshbooks.com/api/me_endpoint
+        See [FreshBooks API - Business, Roles, and Identity](https://www.freshbooks.com/api/me_endpoint)
         """
         return AuthResource(self._client_resource_config()).me_endpoint()
 
     # Accounting Resources
 
+    @property
+    def bills(self) -> AccountingResource:
+        """FreshBooks bills resource with calls to get, list, create, update, delete"""
+        return AccountingResource(
+            self._client_resource_config(), "bills/bills", "bill", "bills"
+        )
+
+    @property
+    def bill_vendors(self) -> AccountingResource:
+        """FreshBooks bill_vendors resource with calls to get, list, create, update, delete"""
+        return AccountingResource(
+            self._client_resource_config(), "bill_vendors/bill_vendors", "bill_vendor", "bill_vendors"
+        )
+
     @property
     def clients(self) -> AccountingResource:
         """FreshBooks clients resource with calls to get, list, create, update, delete"""
